Crate fennel_plugins

Crate fennel_plugins 

Plugins

This crate provides a simple trait for creating plugins within the Fennel engine. Plugins allow to extend the capabilities of the engine, and also are an essential piece of it, as plugins are the backbone for most of the engine’s features.

An example is the fennel_core::plugin::GraphicsPlugin plugin, which provides the most important part of the engine, the graphics.

Traits

Plugin
A trait that all plugins must implement in order to be inserted into App